"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var vue_template_compiler_1 = require("vue-template-compiler");
var loader_utils_1 = require("loader-utils");
exports.parse = function (source) {
    return vue_template_compiler_1.parseComponent(source, { pad: false });
};
/**
 * Given the source of an SFC and a parsed styleblock from an SFC, this method will remove
 * the given style block and return the resulting source.
 *
 * Note that whitespace is preserved for debugging purposes
 */
exports.removeStyleBlock = function (source, styleDescriptor) {
    var start = source.lastIndexOf('<', styleDescriptor.start);
    var end = source.indexOf('>', styleDescriptor.end);
    var lines = source.slice(start, end).split('\n').length;
    return source.substring(0, start)
        + Array(lines).map(function () { return ''; }).join('\n')
        + source.substring(end + 1, source.length);
};
/**
 * Given the source of an SFC and the name of a theme, this method will remove all
 * style blocks that have a theme attribute specified whose value does not equal the
 * given theme name. It will not remove style blocks without a theme attribute specified.
 */
exports.removeOtherThemes = function (source, theme) {
    var styles = exports.parse(source).styles;
    for (var _i = 0, styles_1 = styles; _i < styles_1.length; _i++) {
        var style = styles_1[_i];
        if (style.attrs.theme && style.attrs.theme !== theme) {
            return exports.removeOtherThemes(exports.removeStyleBlock(source, style), theme);
        }
    }
    return source;
};
function vueThemeLoader(source) {
    var _a = (loader_utils_1.getOptions(this) || {}).theme, theme = _a === void 0 ? '' : _a;
    return exports.removeOtherThemes(source, theme);
}
exports.default = vueThemeLoader;
